==> rsbml_1.0-4.tar.gz: rsbml/man/AssignmentRule-class.Rd <==
\name{AssignmentRule-class}
\docType{class}
\alias{AssignmentRule-class}
\alias{type,AssignmentRule-method}
\alias{type}
\alias{type<-,AssignmentRule-method}
\alias{type<-}
\alias{variable,AssignmentRule-method}
\alias{variable<-,AssignmentRule-method}

\title{SBML type "AssignmentRule"}
\description{An equation that assigns a value to the quantity of a 
\code{\linkS4class{Species}}, the size of a \code{\linkS4class{Compartment}} 
or the value of a \code{\linkS4class{Parameter}}.}
\section{Instantiation}{
Objects can be created by calls of the form \code{new("AssignmentRule", ...)}.
}
\section{Slots}{
	 \describe{
    \item{\code{variable}:}{Object of class \code{"character"} naming the
    variable (the id of a \code{\linkS4class{Species}}, \code{\linkS4class{Compartment}}
    or \code{\linkS4class{Parameter}}) to set.}
    \item{\code{type}:}{Object of class \code{"character"}, deprecated. }
    \item{\code{math}:}{Object of class \code{"expression"} specifying the equation. }
    \item{\code{metaId}:}{Object of class \code{"character"} that is an XML ID
      "described" by an RDF resource. This links an SBML element to an RDF
      resource. RDF may appear anywhere in an SBML element,
      but is usually placed inside the \code{annotation} element.}
    \item{\code{notes}:}{Object of class \code{"character"} 
      containing user-readable XHTML notes about an element. }
    \item{\code{annotation}:}{Object of class \code{"character"} containing
      additional machine-readable information about an element, usually as RDF,
      such as BioPAX. This is where application-specific data belongs.}
  }
}
\section{Extends}{
Class \code{"\linkS4class{Rule}"}, directly.
Class \code{"\linkS4class{SBase}"}, by class "Rule", distance 2.
}
\section{Methods}{
  \describe{
    \item{variable}{\code{signature(object = "AssignmentRule")}: gets the \code{variable} slot }
    \item{variable<-}{\code{signature(object = "AssignmentRule")}: sets the \code{variable} slot }
    \item{type}{\code{signature(object = "AssignmentRule")}: gets the \code{type} slot }
    \item{type<-}{\code{signature(object = "AssignmentRule")}: sets the \code{type} slot }
	 }
}
\references{\url{http://sbml.org/documents/}}
\author{Michael Lawrence}
\keyword{classes}

==> rsbml_2.68.0.tar.gz: rsbml/man/AssignmentRule-class.Rd <==
\name{AssignmentRule-class}
\docType{class}
\alias{AssignmentRule-class}
\alias{type,AssignmentRule-method}
\alias{type}
\alias{type<-,AssignmentRule-method}
\alias{type<-}
\alias{variable,AssignmentRule-method}
\alias{variable<-,AssignmentRule-method}

\title{SBML type "AssignmentRule"}
\description{An equation that assigns a value to the quantity of a 
\code{\linkS4class{Species}}, the size of a \code{\linkS4class{Compartment}} 
or the value of a \code{\linkS4class{Parameter}}.}
\section{Instantiation}{
Objects can be created by calls of the form \code{new("AssignmentRule", ...)}.
}
\section{Slots}{
	 \describe{
    \item{\code{variable}:}{Object of class \code{"character"} naming the
    variable (the id of a \code{\linkS4class{Species}}, \code{\linkS4class{Compartment}}
    or \code{\linkS4class{Parameter}}) to set.}
    \item{\code{type}:}{Object of class \code{"character"}, deprecated. }
    \item{\code{math}:}{Object of class \code{"expression"} specifying the equation. }
    \item{\code{metaId}:}{Object of class \code{"character"} that is an XML ID
      "described" by an RDF resource. This links an SBML element to an RDF
      resource. RDF may appear anywhere in an SBML element,
      but is usually placed inside the \code{annotation} element.}
    \item{\code{notes}:}{Object of class \code{"character"} 
      containing user-readable XHTML notes about an element. }
    \item{\code{annotation}:}{Object of class \code{"character"} containing
      additional machine-readable information about an element, usually as RDF,
      such as BioPAX. This is where application-specific data belongs.}
    \item{\code{cvTerms}:}{Object of class \code{"list"} containing
      instances of \code{\linkS4class{CVTerm}} associated with this
      element.}
    \item{\code{sboTerm}:}{Object of class \code{"integer"} identifying
      a term in the Systems Biology Ontology (SBO).}
  }
}
\section{Extends}{
Class \code{"\linkS4class{Rule}"}, directly.
Class \code{"\linkS4class{SBase}"}, by class "Rule", distance 2.
}
\section{Methods}{
  \describe{
    \item{variable}{\code{signature(object = "AssignmentRule")}: gets the \code{variable} slot }
    \item{variable<-}{\code{signature(object = "AssignmentRule")}: sets the \code{variable} slot }
    \item{type}{\code{signature(object = "AssignmentRule")}: gets the \code{type} slot }
    \item{type<-}{\code{signature(object = "AssignmentRule")}: sets the \code{type} slot }
	 }
}
\references{\url{http://sbml.org/documents/}}
\author{Michael Lawrence}
\keyword{classes}
